@@ -26,7 +26,12 @@ let () =
 
   (* Print all files recursively. *)
   let rec print path =
-    if path <> "" then print_endline path;
+    if path <> "" then (
+      let value = Augeas.get aug path in
+      match value with
+      | None -> print_endline path
+      | Some value -> Printf.printf "%s -> '%s'\n%!" path value
+    );
     let files = List.sort compare (Augeas.matches aug (path ^ "/*")) in
     List.iter print files
   in
